/* $Id: jigdo.cc,v 1.22 2002/06/15 18:37:49 richard Exp $ -*- C++ -*-
  __   _
  |_) /|  Copyright (C) 2001-2002 Richard Atterer
  | \/|  <richard@atterer.net>
   '` 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2. See
  the file COPYING for details.

*/

#include <iostream>
#include <string>
namespace std { }
using namespace std;

#include <config.h>
#include <debug.hh>
#include <download.hh>
#include <glibc-getopt.h>
#include <job-download.hh>
#include <gtk-gui.hh>
#include <gtk-support.hh>
#include <string.hh>
//______________________________________________________________________

#if WINDOWS
string packageDataDir;
#endif
//______________________________________________________________________

namespace {

#if WINDOWS
const char* binaryName = "jigdo";
#else
const char* binaryName;
#endif

vector<string> optUris;

void tryHelp() {
  cerr << subst(_("%1: Try `%1 -h' or `man jigdo' for more "
                  "information"), binaryName) << endl;
  exit(3);
}

inline void cmdOptions(int argc, char* argv[]) {
  bool optHelp = false;
  bool optVersion = false;

  if (!WINDOWS) binaryName = argv[0];
  bool error = false;
  while (true) {
    static const struct option longopts[] = {
      { "help",               no_argument,       0, 'h' },
      { "version",            no_argument,       0, 'v' },
      { 0, 0, 0, 0 }
    };
    int c = getopt_long(argc, argv, "hv", longopts, 0);
    if (c == -1) break;
    switch (c) {
    case 'h': optHelp = true; break;
    case 'v': optVersion = true; break;
    case '?': error = true;
    case ':': break;
    default:
#     if DEBUG
      cerr << "getopt returned " << static_cast<int>(c) << endl;
#     endif
      break;
    }
  }
  if (error) tryHelp();
  if (optHelp || optVersion) {
    if (optVersion) cout << "jigdo version " JIGDO_VERSION << endl;
    if (optHelp) cout << subst(_(
    "Usage: %1 [OPTIONS] [URL]\n"
    "Options:\n"
    "  -h  --help       Output help\n"
    "  -v  --version    Output version info"), binaryName) << endl;
    exit(0);
  }
  while (optind < argc) optUris.push_back(argv[optind++]);
}

#if WINDOWS
inline void getPackageDataDir() {
  char buf[MAX_PATH];
  GetModuleFileName(NULL, buf, MAX_PATH);
  char* end = strrchr(buf, '\\');
  packageDataDir.append(buf, end - buf + 1);
}
#endif

} // local namespace
//______________________________________________________________________

int main (int argc, char *argv[]) {
# if WINDOWS
  getPackageDataDir();
# endif
# if ENABLE_NLS
  bindtextdomain(PACKAGE, packageLocaleDir);
  textdomain(PACKAGE);
  if (WINDOWS) bind_textdomain_codeset(PACKAGE, "UTF-8");
# endif

  // Initialize GTK+ and display window
  gtk_set_locale();
  gtk_init(&argc, &argv);
  {
    string pixDir = packageDataDir; pixDir += "pixmaps";
    add_pixmap_directory(pixDir.c_str());
  }
  GUI::create();
  cmdOptions(argc, argv);
  gtk_widget_show(GUI::window.window);

  Download::init();

  // Start downloads of any URIs specified on command line
  string dest = ".";
  for (vector<string>::const_iterator i = optUris.begin(), e = optUris.end();
       i != e; ++i) {
    Job* j = new DownloadJob(*i, dest);
    GUI::jobVector.append(j);
  }
  optUris.clear();

  gtk_main();
  return 0;
}
